use bevy::prelude::StageLabel;

/// An enum representing the current set of systems that should be running.
/// Changing states should be done by inserting an `iyes_loopless` `NextState`
/// resource with the value of one of these app states
#[derive(Clone, Copy, Eq, PartialEq, Ord, PartialOrd, Debug, Hash, StageLabel)]
pub enum AppState {
	/// During the preload state, embedded resources will be registered with Bevy.
	/// Embedded resources will be attached to the asset system with the path
	/// `internal:{resource-name}`
	Preload,
	/// During the setup state, external resources will be registered by reading from
	/// the filesystem or the network. Progress can be displayed using the embedded
	/// resources loaded in the previous state
	Setup,
	/// The splash state exists solely to render attributions & logos before starting
	/// the game
	Splash,
	/// An initial landing page that will present players with options
	Menu,
	/// The in game state runs all of the actual gameplay logic. Most of the runtime
	/// will be spent here.
	InGame,
}
